@@ -576,8 +576,6 @@ void cmdline_input(int meta, int key)
         int rcode = saphire_shell(string_c_str(gCmdLine), "cmdline", pipeout, pipein, STDERR_FILENO);
         saphire_sweep();
         sWFd_flash(pipeout);
-        sWFd_delete(pipeout);
-        sRFd_delete(pipein);
         add_history(string_c_str(gCmdLine));
         set_signal_mfiler();
 
@@ -914,7 +912,6 @@ static void cmdline_view_filer()
         sRFd* rfd = sRFd_new(0);
         saphire_shell3(str, env, "prompt", rfd);
         saphire_sweep();
-        sRFd_delete(rfd);
 
         mmvprintw(maxy -2, 0, "%s", string_c_str(str));
 
